pub struct MemoryType(/* private fields */);Expand description
Potential values for MINIDUMP_MEMORY_INFO::_type
Implementations
Sourceimpl MemoryType
impl MemoryType
pub const MEM_PRIVATE: MemoryType
pub const MEM_MAPPED: MemoryType
pub const MEM_IMAGE: MemoryType
Sourceimpl MemoryType
impl MemoryType
Sourcepub const fn empty() -> MemoryType
pub const fn empty() -> MemoryType
Get a flags value with all bits unset.
Sourcepub const fn all() -> MemoryType
pub const fn all() -> MemoryType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MemoryType>
pub const fn from_bits(bits: u32) -> Option<MemoryType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MemoryType
pub const fn from_bits_truncate(bits: u32) -> MemoryType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MemoryType
pub const fn from_bits_retain(bits: u32) -> MemoryType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MemoryType>
pub fn from_name(name: &str) -> Option<MemoryType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MemoryType) -> bool
pub const fn intersects(&self, other: MemoryType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: MemoryType) -> bool
pub const fn contains(&self, other: MemoryType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: MemoryType)
pub fn insert(&mut self, other: MemoryType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: MemoryType)
pub fn remove(&mut self, other: MemoryType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MemoryType)
pub fn toggle(&mut self, other: MemoryType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: MemoryType, value: bool)
pub fn set(&mut self, other: MemoryType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MemoryType) -> MemoryType
pub const fn intersection(self, other: MemoryType) -> MemoryType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: MemoryType) -> MemoryType
pub const fn union(self, other: MemoryType) -> MemoryType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: MemoryType) -> MemoryType
pub const fn difference(self, other: MemoryType) -> MemoryType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MemoryType) -> MemoryType
pub const fn symmetric_difference(self, other: MemoryType) -> MemoryType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> MemoryType
pub const fn complement(self) -> MemoryType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MemoryType
impl MemoryType
Sourcepub const fn iter(&self) -> Iter<MemoryType>
pub const fn iter(&self) -> Iter<MemoryType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MemoryType>
pub const fn iter_names(&self) -> IterNames<MemoryType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.